@@ -12,7 +12,7 @@ import copy
 from ethereum import opcodes
 import time
 from ethereum.slogging import get_logger
-from rlp.utils import encode_hex, ascii_chr
+from ethereum.utils import encode_hex, ascii_chr
 from ethereum.utils import to_string, encode_int, zpad, bytearray_to_bytestr
 
 log_log = get_logger('eth.vm.log')
