@@ -10,7 +10,7 @@ from ethereum.meta import apply_block
 from ethereum.common import update_block_env_variables
 from ethereum.messages import apply_transaction
 import rlp
-from rlp.utils import encode_hex
+from ethereum.utils import encode_hex
 from ethereum.exceptions import InvalidNonce, InsufficientStartGas, UnsignedTransaction, \
     BlockGasLimitReached, InsufficientBalance, InvalidTransaction, VerificationFailed
 from ethereum.slogging import get_logger, configure_logging
@@ -77,6 +77,11 @@ class Chain(object):
 
         initialize(self.state)
         self.new_head_cb = new_head_cb
+        
+        if self.state.block_number == 0:
+            assert self.state.block_number == self.state.prev_headers[0].number
+        else:
+            assert self.state.block_number - 1 == self.state.prev_headers[0].number
 
         if reset_genesis:
             if isinstance(self.state.prev_headers[0], FakeHeader):
@@ -89,8 +94,6 @@ class Chain(object):
         else:
             self.genesis = self.get_block_by_number(0)
 
-        assert self.state.block_number == self.state.prev_headers[0].number
-
         self.head_hash = self.state.prev_headers[0].hash
         self.time_queue = []
         self.parent_queue = {}
